@@ -1,7 +1,7 @@
 // Licensed under the MIT License
 // https://github.com/craigahobbs/chisel/blob/master/LICENSE
 
-import {decodeParams, href} from './schema-markdown/util.js';
+import {decodeQueryString, encodeHref} from './schema-markdown/encode.js';
 import {SchemaMarkdownParser} from './schema-markdown/parser.js';
 import {UserTypeElements} from './schema-markdown/doc.js';
 import {renderElements} from './schema-markdown/elements.js';
@@ -64,7 +64,7 @@ export class DocPage {
         this.params = null;
 
         // Validate the hash parameters (may throw)
-        this.params = validateType(docPageTypes, 'DocPageParams', decodeParams(params));
+        this.params = validateType(docPageTypes, 'DocPageParams', decodeQueryString(params));
     }
 
     // Helper function to render the documentation application page
@@ -159,7 +159,7 @@ export class DocPage {
                     'elem': {'html': 'li', 'elem': {'html': 'ul', 'elem': index.groups[group].sort().map(
                         (name) => ({
                             'html': 'li',
-                            'elem': {'html': 'a', 'attr': {'href': href({...this.params, 'name': name})}, 'elem': {'text': name}}
+                            'elem': {'html': 'a', 'attr': {'href': encodeHref({...this.params, 'name': name})}, 'elem': {'text': name}}
                         })
                     )}}
                 }
@@ -180,7 +180,7 @@ export class DocPage {
                 'html': 'p',
                 'elem': {
                     'html': 'a',
-                    'attr': {'href': href(indexParams)},
+                    'attr': {'href': encodeHref(indexParams)},
                     'elem': {'text': 'Back to documentation index'}
                 }
             },
